==> libqt4-appdownloader-comm_0.3.tar.gz: libqt4-appdownloader-comm-0.3/src/MaemoApplicationDetails.h <==
#ifndef MAEMOAPPLICATIONDETAILS_H
#define MAEMOAPPLICATIONDETAILS_H

#include "MaemoApplication.h"
#include "MaemoComment.h"
#include <QObject>

class MaemoApplicationDetails : public MaemoApplication {
    Q_OBJECT

    public:
        MaemoApplicationDetails();
        ~MaemoApplicationDetails();
        //set parameters
        void setDesc (QString);
        void setLicence (QString);
        void setStatus (QString);
        void setInstallFile (QString);
        void setInstallFileContent (QString);
        void setRevisor (QString);
        void addScreenshot (QString);
        void addUserComment (MaemoComment*);
        void setUnparsedComments (QString*);


        //get parameters
        QString getDescription ();
        QString getLicence ();
        QString getStatus ();
        QString getInstallFile ();
        QList <QString>* getScreenShots ();
        QString getInstallFileContent ();
        QString getFirstScreenShot ();
        QList <MaemoComment*>* getUserComments();
        QString * getUnparsedComments ();

        //output as a QString
        QString toString ();

    public slots:
        void setCommentsList (QList <MaemoComment*> *);

    private:
        QString desc;
        QString licence;
        QString status;
        QString installFile;
        QString installFileContent;
        QString revisor;
        QList <QString> *screenshots;
        QList <MaemoComment*> *userComments;
        QString *unparsedComments;

    };
#endif // MAEMOAPPLICATIONDETAILS_H

==> libqt4-appdownloader-comm_0.3.2.tar.gz: libqt4-appdownloader-comm-0.3.2/src/MaemoApplicationDetails.h <==
#ifndef MAEMOAPPLICATIONDETAILS_H
#define MAEMOAPPLICATIONDETAILS_H

#include "MaemoApplication.h"
#include "MaemoComment.h"
#include <QObject>

class MaemoApplicationDetails : public MaemoApplication {
    Q_OBJECT

    public:
        MaemoApplicationDetails();
        ~MaemoApplicationDetails();
        //set parameters
        void setDesc (QString);
        void setLicence (QString);
        void setStatus (QString);
        void setInstallFile (QString);
        void setInstallFileContent (QString);
        void setRevisor (QString);
        void addScreenshot (QString);
        void addUserComment (MaemoComment*);
        void setUnparsedComments (QByteArray);


        //get parameters
        QString getDescription ();
        QString getLicence ();
        QString getStatus ();
        QString getInstallFile ();
        QList <QString>* getScreenShots ();
        QString getInstallFileContent ();
        QString getFirstScreenShot ();
        QList <MaemoComment*>* getUserComments();
        QByteArray getUnparsedComments ();

        //output as a QString
        QString toString ();

    public slots:
        void setCommentsList (QList <MaemoComment*> *);

    private:
        QString desc;
        QString licence;
        QString status;
        QString installFile;
        QString installFileContent;
        QString revisor;
        QList <QString> *screenshots;
        QList <MaemoComment*> *userComments;
        QByteArray unparsedComments;

    };
#endif // MAEMOAPPLICATIONDETAILS_H
